@@ -102,7 +102,7 @@ class snowflake_processor:
 
         try:
             engine = create_engine(
-                "snowflake://{user}:{password}@{account_identifier}/".format(
+                "snowflake://{user}:{password}@{account}/{db}/{schema}?warehouse={warehouse}".format(
                     user = self.credentials.get('username'),
                     password = self.credentials.get('password'),
                     account = self.credentials.get('account'),
